@@ -654,7 +654,7 @@ RCP<const Number> ComplexMPC::rpow(const RealMPFR &other) const
 //! Evaluate functions with double precision
 class EvaluateMPC : public Evaluate
 {
-    virtual RCP<const Basic> sin(const Basic &x) const override
+    RCP<const Basic> sin(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -663,7 +663,7 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> cos(const Basic &x) const override
+    RCP<const Basic> cos(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -672,7 +672,7 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> tan(const Basic &x) const override
+    RCP<const Basic> tan(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -681,7 +681,7 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> cot(const Basic &x) const override
+    RCP<const Basic> cot(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -691,7 +691,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> sec(const Basic &x) const override
+    RCP<const Basic> sec(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -701,7 +701,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> csc(const Basic &x) const override
+    RCP<const Basic> csc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -711,7 +711,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> asin(const Basic &x) const override
+    RCP<const Basic> asin(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -720,7 +720,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acos(const Basic &x) const override
+    RCP<const Basic> acos(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -729,7 +729,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> atan(const Basic &x) const override
+    RCP<const Basic> atan(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -738,7 +738,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acot(const Basic &x) const override
+    RCP<const Basic> acot(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -748,7 +748,7 @@ class EvaluateMPC : public Evaluate
         mpc_atan(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> asec(const Basic &x) const override
+    RCP<const Basic> asec(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -758,7 +758,7 @@ class EvaluateMPC : public Evaluate
         mpc_acos(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acsc(const Basic &x) const override
+    RCP<const Basic> acsc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -768,7 +768,7 @@ class EvaluateMPC : public Evaluate
         mpc_asin(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> sinh(const Basic &x) const override
+    RCP<const Basic> sinh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -777,7 +777,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> csch(const Basic &x) const override
+    RCP<const Basic> csch(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -787,7 +787,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> cosh(const Basic &x) const override
+    RCP<const Basic> cosh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -796,7 +796,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> sech(const Basic &x) const override
+    RCP<const Basic> sech(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -806,7 +806,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> tanh(const Basic &x) const override
+    RCP<const Basic> tanh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -815,7 +815,7 @@ class EvaluateMPC : public Evaluate
                  MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> coth(const Basic &x) const override
+    RCP<const Basic> coth(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -825,7 +825,7 @@ class EvaluateMPC : public Evaluate
         mpc_ui_div(t.get_mpc_t(), 1, t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> asinh(const Basic &x) const override
+    RCP<const Basic> asinh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -834,7 +834,7 @@ class EvaluateMPC : public Evaluate
                   MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acsch(const Basic &x) const override
+    RCP<const Basic> acsch(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -844,7 +844,7 @@ class EvaluateMPC : public Evaluate
         mpc_asinh(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acosh(const Basic &x) const override
+    RCP<const Basic> acosh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -853,7 +853,7 @@ class EvaluateMPC : public Evaluate
                   MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> atanh(const Basic &x) const override
+    RCP<const Basic> atanh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -862,7 +862,7 @@ class EvaluateMPC : public Evaluate
                   MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> acoth(const Basic &x) const override
+    RCP<const Basic> acoth(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -872,7 +872,7 @@ class EvaluateMPC : public Evaluate
         mpc_atanh(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> asech(const Basic &x) const override
+    RCP<const Basic> asech(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -882,7 +882,7 @@ class EvaluateMPC : public Evaluate
         mpc_acosh(t.get_mpc_t(), t.get_mpc_t(), MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> log(const Basic &x) const override
+    RCP<const Basic> log(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -891,7 +891,7 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> abs(const Basic &x) const override
+    RCP<const Basic> abs(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpfr_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -900,11 +900,11 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> gamma(Basic const &aConst) const override
+    RCP<const Basic> gamma(Basic const &aConst) const override
     {
         throw NotImplementedError("Not Implemented.");
     }
-    virtual RCP<const Basic> exp(const Basic &x) const override
+    RCP<const Basic> exp(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         mpc_class t(down_cast<const ComplexMPC &>(x).as_mpc().get_prec());
@@ -913,7 +913,7 @@ class EvaluateMPC : public Evaluate
                 MPFR_RNDN);
         return complex_mpc(std::move(t));
     }
-    virtual RCP<const Basic> floor(const Basic &x) const override
+    RCP<const Basic> floor(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         integer_class re, im;
@@ -930,7 +930,7 @@ class EvaluateMPC : public Evaluate
         return Complex::from_two_nums(*integer(std::move(re)),
                                       *integer(std::move(im)));
     }
-    virtual RCP<const Basic> ceiling(const Basic &x) const override
+    RCP<const Basic> ceiling(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         integer_class re, im;
@@ -947,7 +947,7 @@ class EvaluateMPC : public Evaluate
         return Complex::from_two_nums(*integer(std::move(re)),
                                       *integer(std::move(im)));
     }
-    virtual RCP<const Basic> truncate(const Basic &x) const override
+    RCP<const Basic> truncate(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         integer_class re, im;
@@ -964,12 +964,12 @@ class EvaluateMPC : public Evaluate
         return Complex::from_two_nums(*integer(std::move(re)),
                                       *integer(std::move(im)));
     }
-    virtual RCP<const Basic> erf(const Basic &x) const override
+    RCP<const Basic> erf(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         throw NotImplementedError("erf is not implemented in mpc");
     }
-    virtual RCP<const Basic> erfc(const Basic &x) const override
+    RCP<const Basic> erfc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<ComplexMPC>(x))
         throw NotImplementedError("erfc is not implemented in mpc");
