@@ -696,7 +696,7 @@ RCP<const Number> RealMPFR::rpowreal(const ComplexDouble &other) const
 //! Evaluate functions with double precision
 class EvaluateMPFR : public Evaluate
 {
-    virtual RCP<const Basic> sin(const Basic &x) const override
+    RCP<const Basic> sin(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -704,7 +704,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> cos(const Basic &x) const override
+    RCP<const Basic> cos(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -712,7 +712,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> tan(const Basic &x) const override
+    RCP<const Basic> tan(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -720,7 +720,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> cot(const Basic &x) const override
+    RCP<const Basic> cot(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -728,7 +728,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> sec(const Basic &x) const override
+    RCP<const Basic> sec(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -736,7 +736,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> csc(const Basic &x) const override
+    RCP<const Basic> csc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -744,7 +744,7 @@ class EvaluateMPFR : public Evaluate
                  MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> asin(const Basic &x) const override
+    RCP<const Basic> asin(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -763,7 +763,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> acos(const Basic &x) const override
+    RCP<const Basic> acos(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -782,7 +782,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> atan(const Basic &x) const override
+    RCP<const Basic> atan(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -790,7 +790,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> acot(const Basic &x) const override
+    RCP<const Basic> acot(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -799,7 +799,7 @@ class EvaluateMPFR : public Evaluate
         mpfr_atan(t.get_mpfr_t(), t.get_mpfr_t(), MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> asec(const Basic &x) const override
+    RCP<const Basic> asec(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -820,7 +820,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> acsc(const Basic &x) const override
+    RCP<const Basic> acsc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -841,7 +841,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> sinh(const Basic &x) const override
+    RCP<const Basic> sinh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -849,7 +849,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> csch(const Basic &x) const override
+    RCP<const Basic> csch(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -857,7 +857,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> cosh(const Basic &x) const override
+    RCP<const Basic> cosh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -865,7 +865,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> sech(const Basic &x) const override
+    RCP<const Basic> sech(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -873,7 +873,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> tanh(const Basic &x) const override
+    RCP<const Basic> tanh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -881,7 +881,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> coth(const Basic &x) const override
+    RCP<const Basic> coth(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -889,7 +889,7 @@ class EvaluateMPFR : public Evaluate
                   MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> asinh(const Basic &x) const override
+    RCP<const Basic> asinh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -897,7 +897,7 @@ class EvaluateMPFR : public Evaluate
                    down_cast<const RealMPFR &>(x).i.get_mpfr_t(), MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> acsch(const Basic &x) const override
+    RCP<const Basic> acsch(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -906,7 +906,7 @@ class EvaluateMPFR : public Evaluate
         mpfr_asinh(t.get_mpfr_t(), t.get_mpfr_t(), MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> acosh(const Basic &x) const override
+    RCP<const Basic> acosh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -925,7 +925,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> atanh(const Basic &x) const override
+    RCP<const Basic> atanh(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -944,7 +944,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> acoth(const Basic &x) const override
+    RCP<const Basic> acoth(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -965,7 +965,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> asech(const Basic &x) const override
+    RCP<const Basic> asech(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -986,7 +986,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> log(const Basic &x) const override
+    RCP<const Basic> log(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1005,7 +1005,7 @@ class EvaluateMPFR : public Evaluate
             "Result is complex. Recompile with MPC support.");
 #endif
     }
-    virtual RCP<const Basic> abs(const Basic &x) const override
+    RCP<const Basic> abs(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_class t(down_cast<const RealMPFR &>(x).i.get_prec());
@@ -1014,7 +1014,7 @@ class EvaluateMPFR : public Evaluate
         return real_mpfr(std::move(t));
     }
 
-    virtual RCP<const Basic> gamma(const Basic &x) const override
+    RCP<const Basic> gamma(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1026,7 +1026,7 @@ class EvaluateMPFR : public Evaluate
             throw NotImplementedError("Not Implemented.");
         }
     }
-    virtual RCP<const Basic> exp(const Basic &x) const override
+    RCP<const Basic> exp(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1034,7 +1034,7 @@ class EvaluateMPFR : public Evaluate
         mpfr_exp(t.get_mpfr_t(), x_, MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> floor(const Basic &x) const override
+    RCP<const Basic> floor(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1043,7 +1043,7 @@ class EvaluateMPFR : public Evaluate
         mp_demote(i);
         return integer(std::move(i));
     }
-    virtual RCP<const Basic> ceiling(const Basic &x) const override
+    RCP<const Basic> ceiling(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1052,7 +1052,7 @@ class EvaluateMPFR : public Evaluate
         mp_demote(i);
         return integer(std::move(i));
     }
-    virtual RCP<const Basic> truncate(const Basic &x) const override
+    RCP<const Basic> truncate(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1061,7 +1061,7 @@ class EvaluateMPFR : public Evaluate
         mp_demote(i);
         return integer(std::move(i));
     }
-    virtual RCP<const Basic> erf(const Basic &x) const override
+    RCP<const Basic> erf(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
@@ -1069,7 +1069,7 @@ class EvaluateMPFR : public Evaluate
         mpfr_erf(t.get_mpfr_t(), x_, MPFR_RNDN);
         return real_mpfr(std::move(t));
     }
-    virtual RCP<const Basic> erfc(const Basic &x) const override
+    RCP<const Basic> erfc(const Basic &x) const override
     {
         SYMENGINE_ASSERT(is_a<RealMPFR>(x))
         mpfr_srcptr x_ = down_cast<const RealMPFR &>(x).i.get_mpfr_t();
